@@ -3,7 +3,7 @@ use proc_macro::TokenStream;
 mod route;
 mod router;
 
-type Result<T> = std::result::Result<T, syn::Error>;
+type Result<T> = core::result::Result<T, syn::Error>;
 
 pub(crate) static ROUTE_STRUCT_PREFIX: &str = "ROUTE_FOR_";
 pub(crate) static ROUTE_STRUCT_SUFFIX: &str = "_INSTANCE";
