@@ -59,7 +59,7 @@ fn uri_path_to_segments(path: syn::LitStr) -> crate::Result<Segments> {
     Ok(segments)
 }
 
-pub fn route_attribute(method: &'static str, args: TokenStream, input: TokenStream) -> TokenStream {
+pub fn route_attribute(method: &str, args: TokenStream, input: TokenStream) -> TokenStream {
     let http_method = method.to_string().to_uppercase();
     let wrapped_fn = parse_macro_input!(input as syn::ItemFn);
 
@@ -79,15 +79,19 @@ pub fn route_attribute(method: &'static str, args: TokenStream, input: TokenStre
         .sum();
     let glob_position = segments.iter().position(|s| matches!(s, Segment::Glob));
 
-    // enforce that glob is last
-    if let Some(position) = glob_position {
-        if segments.len() - 1 != position {
-            return syn::Error::new(attribute.span(), "'**' may only be at the end of a path")
-                .into_compile_error()
-                .into();
+    let glob_state = match glob_position {
+        Some(pos) if pos == 0 => quote! { ::mimeograph_router::GlobState::Begin },
+        Some(pos) if pos == segments.len() - 1 => quote! { ::mimeograph_router::GlobState::End },
+        Some(_) => {
+            return syn::Error::new(
+                attribute.span(),
+                "'**' may only be at the beginning or end of a path",
+            )
+            .into_compile_error()
+            .into();
         }
-    }
-    let has_glob = glob_position.is_some();
+        None => quote! { ::mimeograph_router::GlobState::None },
+    };
 
     let struct_instance_name = quote::format_ident!(
         "{}{}{}",
@@ -149,7 +153,7 @@ pub fn route_attribute(method: &'static str, args: TokenStream, input: TokenStre
             method: #http_method,
             segments: &[#(#segments),*],
             wrapper: &#wrapper_fn_name,
-            has_glob: #has_glob,
+            glob: #glob_state,
             args_count: #segment_arg_count,
         };
     };
